/* 
    cmotech-cdswitch - Switch CNU-680
    Copyright (C) 2008 Peter Åstrand <astrand@lysator.liu.se>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <stdio.h>		/* fprintf */
#include <unistd.h>		/* close */
#include <string.h>		/* memcpy */
#include <fcntl.h>		/* open */
#include <sys/ioctl.h>		/* ioctl */
#include <stdlib.h>		/* exit */
#include <scsi/scsi_ioctl.h>	/* SCSI_IOCTL_SEND_COMMAND */

typedef struct scsi_ioctl_command
{
    unsigned int inlen;
    unsigned int outlen;
    /* The original code was using only 10 bytes, but that corrupts
       other variables. From the SCSI HOWTO:

       "The length (x + y) must be at least OMAX_SB_LEN bytes long to
       accommodate the sense buffer when an error occurs. The sense
       buffer is truncated to OMAX_SB_LEN (16) bytes so that old code
       will not be surprised." */
    unsigned char data[16];
} Scsi_Ioctl_Command;


int
main(int argc, char *argv[])
{
    const char *device;
    Scsi_Ioctl_Command cmd = { 0 };
    int cmdret = 0;
    int fd;

    if (argc != 2) {
	fprintf(stderr, "Usage: %s <sg-device>\n", argv[0]);
	exit(1);
    }

    device = argv[1];

    fd = open(device, O_RDWR);
    if (fd < 0) {
	perror("Unable to open device");
	exit(2);
    }

    cmd.inlen = 9;
    cmd.outlen = 0;
    memcpy(cmd.data, "\xffRDEVCHG1", 9);

    cmdret = ioctl(fd, SCSI_IOCTL_SEND_COMMAND, &cmd);
    if (cmdret < 0) {
	perror("ioctl SCSI_IOCTL_SEND_COMMAND failed");
	exit(3);
    }

    close(fd);

    return 0;
}
